
#include <stdbool.h>
#include "nrf.h"
#include "nrf_error.h"

#include "nrf_gpio.h"
#include "boards.h"
#include "pstorage.h"
#include "intFlash.h"
#include "pstorage_platform.h"

#define BLOCK_SIZE 0x10
#define BLOCK_COOUNT 60


static bool flasRest = false;
static pstorage_handle_t base_handle;
static pstorage_handle_t block_handle;
typedef struct
{
      pstorage_ntf_cb_t   example_cb_handler;                   
} cb_init;

void example_cb_handler(pstorage_handle_t *  p_handle,
                              uint8_t              op_code,
                              uint32_t             result,
                              uint8_t *            p_data,
                              uint32_t             data_len)
{
  switch(op_code)
    {

       case PSTORAGE_STORE_OP_CODE:
           if (result == NRF_SUCCESS)
           {
               flasRest = true;
           }
           else
           {
               // Store operation failed.
           }
           // Source memory can now be reused or freed.
           break;
				case PSTORAGE_UPDATE_OP_CODE:
           if (result == NRF_SUCCESS)
           {
               // Update operation successful.
           }
           else
           {
               // Update operation failed.
           }
           break;	 
				case PSTORAGE_CLEAR_OP_CODE:
           if (result == NRF_SUCCESS)
           {
               // Clear operation successful.
						 flasRest=true;
           }
           else
           {
               // Clear operation failed.
           }
           break;
    }
}

static uint32_t registerModule(pstorage_module_param_t param)
{
	uint32_t retval;
	retval = pstorage_register(&param, &base_handle);
	if (retval == NRF_SUCCESS)
	{
			// Registration successful.
	}
	else
	{
			// Failed to register, take corrective action.
		return retval;
	}
	return retval;
}
uint32_t IntFlashInit(void)
{
	uint32_t retval;

	
	retval = pstorage_init();
	if(retval == NRF_SUCCESS)
	{
			// Module initialization successful.
	}
	else
	{
		 // Initialization failed, take corrective action.
		return retval;
	}
  pstorage_module_param_t param;  
	
	param.block_size  = BLOCK_SIZE;
	param.block_count = BLOCK_COOUNT;
	param.cb          = example_cb_handler;
	
	retval = registerModule(param);
	
	retval = pstorage_block_identifier_get(&base_handle, 0, &block_handle);
	if (retval == NRF_SUCCESS)
	{
			// Get Block Identifier successful.
	}
	else
	{
			return retval;
	}
	
	//retval = pstorage_clear(&block_handle, BLOCK_SIZE * BLOCK_COOUNT);
	retval =IntFlashErase(0,BLOCK_SIZE,true);
	if (retval == NRF_SUCCESS)
	{
			
	}
	else
	{
			// Failed to request clear, take corrective action.
		return retval;
	}

	return retval;
}
uint32_t IntFlashErase(uint32_t block_add,uint32_t size,bool all)
{
	uint32_t          retval; 
	retval = pstorage_block_identifier_get(&base_handle, block_add, &block_handle);
	if (retval == NRF_SUCCESS)
	{
			// Get Block Identifier successful.
	}
	else
	{
			return retval;
	}	
	if(all)
	{
		retval = pstorage_clear(&block_handle, BLOCK_SIZE * BLOCK_COOUNT);
	}else{
		retval = pstorage_clear(&block_handle, BLOCK_SIZE);
	}
	if (retval == NRF_SUCCESS)
	{
			// Clear successfully requested. Wait for operation result.
			flasRest = false;
	}
	else
	{
			// Failed to request clear, take corrective action.
		return retval;
	}
	while(flasRest == false);
	return retval;
}

uint32_t IntFlashRead(uint8_t *rData,uint32_t block_add,uint32_t size,uint32_t offset)
{
	uint32_t          retval;
  retval = pstorage_block_identifier_get(&base_handle, block_add, &block_handle);
		if (retval == NRF_SUCCESS)
		{
				// Get Block Identifier successful.
				flasRest = false;
		}
		else
		{
				return retval;
		}
	retval = pstorage_load(rData,&block_handle,size,offset);
		if (retval == NRF_SUCCESS)
		{
				// Get Block Identifier successful.
				flasRest = false;
		}
		else
		{
				return retval;
		}
	return retval;
}
uint32_t IntFlashWrite(uint8_t *data,uint32_t block_add,uint32_t size)
{
	uint32_t          retval;  
	
	retval = IntFlashErase(block_add,size,false);
	if (retval == NRF_SUCCESS)
	{
			// Get Block Identifier successful.
			
	}
	else
	{
			return retval;
	}
	retval = pstorage_store(&block_handle,data,size,0);
	if (retval == NRF_SUCCESS)
	{
			// Get Block Identifier successful.
			flasRest = false;
	}
	else
	{
			return retval;
	}
	while(flasRest == false);
	return retval;
}

/** @} */
